#
# spec file for package syzkaller
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define version_unconverted 0.0+git.20160902
Name:           syzkaller
Version:        0.0+git.20160902
Release:        lp152.3.10
Summary:        Distributed, unsupervised, coverage-guided Linux syscall fuzzer
License:        Apache-2.0
Group:          Development/Tools/Other
Url:            https://github.com/google/syzkaller
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  go >= 1.4
BuildRequires:  golang-packaging
BuildRequires:  make
BuildRequires:  xz
# for -fsanitize-coverage
Recommends:     gcc6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64 aarch64 ppc64le
%{go_provides}

%description
syzkaller is a distributed, unsupervised, coverage-guided Linux syscall fuzzer.
It is meant to be used with KASAN (CONFIG_KASAN=y), KTSAN (CONFIG_KTSAN=y), or
KUBSAN.

%prep
%setup -q

%build
%goprep github.com/google/syzkaller
%gobuild ...

mkdir bin
make %{?_smp_mflags} CFLAGS="%{optflags}" NOSTATIC=1 executor

%install
%goinstall
install -m 0755 bin/syz-executor %{buildroot}/%{_bindir}

rm -rf $RPM_BUILD_ROOT%{go_contribdir} $RPM_BUILD_ROOT%{_bindir}/sysgen

%files
%defattr(-,root,root)
%doc AUTHORS CONTRIBUTORS LICENSE README.md syz-manager/example.cfg structure.png sys/sys.txt tools/create-image.sh
%{_bindir}/syz-execprog
%{_bindir}/syz-executor
%{_bindir}/syz-extract
%{_bindir}/syz-fuzzer
%{_bindir}/syz-manager
%{_bindir}/syz-mutate
%{_bindir}/syz-prog2c
%{_bindir}/syz-report
%{_bindir}/syz-repro
%{_bindir}/syz-stress
%{_bindir}/syz-upgrade

%changelog
* Thu Feb  9 2017 jslaby@suse.com
- Update to version 0.0+git.20160902:
  * sys/sysgen/prog: support ranged int
  * sys: regenerate syscall descriptions with latest linux sources
  * reformat sources
  * prog: generate ints outside of the specified range once in a while
  * sys: change int range to use ':' instead of '~'
  * sys: use ranged int in few syscalls so that it is tested
  * ipc: read out executor output
  * prog: generate SIGSEGVs with lower probability
  * host: detect at least some unsupported syscalls if kallsyms is not available
  * vm/qemu: use -no-reboot and -display=none
  * prog: don't try to execute ioctl(FIFREEZE) and mknod
  * fuzzer: prioritize triaging of existing corpus on start
  * manager: measure execution speed starting from first VM connect
  * vm/qemu: support 9p host-based image
  * executor: add experimental mode to skip paging faults
  * overhaul syscall description generation process
  * extract.sh: add a comment with required package names
  * sys: fix skipping of syscalls with unknown constants
  * sysgen: fix generation of flags
  * sys: update README to describe the new 2-step generation process
  * sys: fix links and formatting in README.md
  * Fix configuration anchor link
  * sys: specify resources in text descriptions
  * manager: ignore .git dir in corpus
  * csource: support nonfailing argument copyin/copyout
  * repro: use correct sandbox mode
  * executor, csource: share some common code between executor and csource
  * sysgen: sort resources by name to avoid unnecessary diffs
  * csource: teach how to execute pseudo syz_ syscalls
  * csource: make collide mode more random
  * vm: merger console/fuzzer output line-by-line
  * repro: a little bit more graceful shutdown
  * sys: fix incorrect argument type introduced in 76906672672365b9e31328a0047baf62db9190b6
  * vm: fix potential deadlock in OutputMerger
  * vm/adb: support multiple adb devices
  * report: add a new package for report parsing and processing
  * report: extract better, unique identifiers of oopses
  * symbolizer: move symbolizer to a separate package
  * manager: mark covered lines with /*covered*/
  * report: add a function that symbolizes reports
  * manager: improve how crashes are saved
  * prog: generate shifted integers with some probability
  * manager, repro: unify VM monitoring
  * sysgen: check that structs are not passed as syscall arguments
  * Makefile: format after generate
* Sun Aug  7 2016 mpluskal@suse.com
- Update to version 0.0+git.20160805:
  * add a initrd flag for qemu type and display the qemu command.
  * executor: add support for 386 arch (COMPAT syscalls)
  * config: detect unknown fields in configs
  * executor: revive setuid sandbox
  * added an optional initrd flag.
  * config: add Initrd to known fields
  * manager: pass -debug flag to fuzzer
  * ipc: fix broken test
  * manager: print keep alive to stdout
  * manager: add a special VM type "none"
- Require go 1.4 at least
* Mon Jun 20 2016 jslaby@suse.com
- Update to version 0.0+git.20160615:
  * Use readelf to obtain the upper 32 bits of addresses returned by kcov.
  * Update README.md
  * sys: support getsockopt for sctp
  * sys: support kcm and netrom
  * sys: update generated files
  * stress: fix "assignment to entry in nil map" panic
* Wed Jun  8 2016 mpluskal@suse.com
- Update to version 0.0+git.20160606:
  * Makefile: Split generate: target
  * sysgen: Cope with non-inline kernel build
  * Document how to add new system calls
  * Add debug logging to sysgen/ code
  * sys: add removed defines to fix generate in linux-next
  * Update README.md
  * stress: print program and output on more types of bugs
  * added note for email based subsciption for the mailinglist
  * Use readelf to obtain the upper 32 bits of addresses returned by kcov.
  * Update README.md
* Fri May 13 2016 mpluskal@suse.com
- Exclude building to architectures which have native go compiler
* Fri May 13 2016 jslaby@suse.com
- update to 0.0+git.20160503:
  * use readelf to obtain the upper 32 bits of addresses returned by kcov.
  * added note for email based subsciption for the mailinglist
  * stress: print program and output on more types of bugs
  * update README.md
* Thu Mar 24 2016 jslaby@suse.com
- update to 20160315
  * sys: add removed defines to fix generate in linux-next
  * Add debug logging to sysgen/ code
  * Document how to add new system calls
  * sysgen: Cope with non-inline kernel build
* Fri Mar 11 2016 jslaby@suse.com
- update to 20160310
  * Update README.md
  * executor: prevent test processes from ptracing parent processes
  * executor: ignore NOFILE errors during cleanup
  * executor: ignore the case when test process kills loop process
  * executor: make loop killing non-fatal
  * fuzzer: improve kmemleak logic
  * ipc: increase default response timeout
  * manager: dump machine state on hangs
  * manager: don't save crashers during shutdown
  * vm/qemu: strip ssh warnings
  * sys: add missing include
* Thu Mar  3 2016 jslaby@suse.com
- update to 20160219
  * config: fix calculation of enabled syscalls
  * csource: use dynamic libraries if static are not supported
  * manager: don't confuse users with zero coverage
  * properly cleanup on ctrl+C
  * Update README for dropprivs, troubleshooting
  * More logging from syz-fuzzer
  * Pass through -v <N> option from syz-manager to syz-fuzzer
  * Distinguish between no data and no symbols
- drop no-static.patch
* Thu Feb 18 2016 jslaby@suse.com
- update to 20160216
- add no-static.patch
* Tue Feb 16 2016 jslaby@suse.com
- update to 20160215
- remove allow-empty-kernel.patch: it's upstream
* Thu Feb 11 2016 jslaby@suse.com
- change require gcc6 to recommends
* Wed Feb 10 2016 jslaby@suse.com
- make and install all tools
- add: allow-empty-kernel.patch
* Tue Feb  9 2016 jslaby@suse.com
- update to 20160207
* Tue Feb  2 2016 jslaby@suse.com
- update to 20160128
  * more syscalls and devices tested
- require gcc6
* Tue Jan 26 2016 jslaby@suse.com
- update to 20160125
- remove build-flags.patch: not needed anymore
* Tue Dec  1 2015 jslaby@suse.com
- update to 20151129
- add example.cfg and structure.png
* Fri Nov 27 2015 jslaby@suse.com
- update to 20151126
* Wed Nov 11 2015 jslaby@suse.com
- initial package (20151109)
